When writing tests for this library:
1. Always use pytest
2. assume an appropriate test file already exists, find it, and suggest tests get appended to that file. If no such file exists, ask me before assuming a new test file is the correct route.
3. Test brevity is important. Use approaches for re-use and brevity including using fixtures for repeated code, and using pytest parameterize for similar tests
4. After writing a new test, run it and ensure it works. Fix any issues you find.
